@@ -2,9 +2,9 @@ package Data::Record::Serialize::Role::Base;
 
 use Moo::Role;
 
-our $VERSION = '0.09'; # TRIAL
+our $VERSION = '0.10'; # TRIAL
 
-use Types::Standard qw[ ArrayRef HashRef Enum Str Bool ];
+use Types::Standard qw[ ArrayRef HashRef Enum Str Bool is_HashRef ];
 
 use POSIX ();
 use Carp;
@@ -174,6 +174,14 @@ has format_types => (
 has rename_fields => (
     is      => 'ro',
     isa     => HashRef [Str],
+    coerce  => sub {
+        return $_[0] unless is_HashRef( $_[0] );
+
+        # remove renames which do nothing
+        my %rename = %{ $_[0] };
+        delete @rename{ grep { $rename{$_} eq $_ } keys %rename };
+        return \%rename;
+    },
     default => sub { {} },
     trigger => 1,
 );
@@ -229,8 +237,9 @@ has _format => (
                 }
 
             }
-            return \%format;
 
+            return \%format
+              if keys %format;
         }
 
         return;
@@ -326,7 +335,7 @@ Data::Record::Serialize::Role::Base
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =begin pod_coverage
 
